#!/bin/bash
# Martin Schniewind 2012, http://www.schniewind-it.de
# Beseitigt beobachtete Probleme nach Aktualisierung Von Ubuntu auf Version 12.04.1
#
SV="1.1"
LOG="/tmp/$(basename $0 .sh).log"
declare ERRORS
ERRORS=0
DIST=$(lsb_release -rs)

[ -z "$DIST" ] && echo "Konnte aktuelle Versionsnummer nicht ermitteln - Abbruch" >&2 && exit 1

if [ "${DIST}" != "12.04" ]; then
	echo "Dieses Skript kann nur unter Ubuntu 12.04 eingesetzt werden. Abbruch." >&2
	exit 2
fi

# muss von Root ausgeführt werden:
if [ "$UID" -ne 0 ]; then
	echo "Das Skript erfordert Systemverwaltungsrechte. Bitte geben Sie ihr Kennwort ein."
	sudo $0
	exit 0
fi

#
# Die Ausgabe von allem Folgenden sowohl auf die Konsole als auch in das Logfile schreiben:
#
{
#

# überzählige Dateien in sources.list.d entfernen, falls vorhanden
if ls /etc/apt/sources.list.d/*.liste >/dev/null 2>&1; then
	echo "entferne unbenutzte Fremdpaketquellen (*.liste)..."
	rm /etc/apt/sources.list.d/*.liste 2>/dev/null
	sleep 1
fi

# nicht mehr benoetigte Pakete entfernen
echo "entferne nicht mehr verwendete Programme..."
apt-get --yes autoremove
sleep 1

echo "fehlende Programme installieren: Menu Bar Integration, UbuntuOne, LibreOffice Hilfe, -Sprache, -Datenbank"
ERRID=1
apt-get --yes install indicator-appmenu ubuntuone-client libreoffice libreoffice-help-de libreoffice-l10n-de || ERRORS=$(( $ERRORS + $ERRID ))
sleep 1

# war Cups-PDF installiert?
if [ -d "$HOME/PDF" ]; then
	echo "cups-pdf wieder installieren..."
	ERRID=2
	apt-get --yes install cups-pdf || ERRORS=$(( $ERRORS + $ERRID ))
	sleep 1
fi

# Wenn Moneyplex installiert ist: Start-Skript anpassen und GTK-Bibliothek umbenennen
if [ -d "$HOME"/.moneyplex ]; then
	if ! grep -q "LC_ALL=de_DE.iso-8859-1" "$HOME"/.moneyplex/start; then
		echo "Moneyplex: Umlaute-Problem: LC_ALL und LANG anpassen..."
		ERRID=4
		sed -i -e 's/export LC_ALL=.*/export LC_ALL=de_DE.iso-8859-1/' \
			-e 's/export LANG=.*/export LANG=de_DE.iso-8859-1/' \
			"$HOME"/.moneyplex/start || ERRORS=$(( $ERRORS + $ERRID ))
	fi
	
	if [ -f "$HOME"/.moneyplex/libmatricagtk.so ]; then
		echo "Moneyplex: libmatricagtk.so durch Umbenennen von der Verwendung ausnehmen..."
		ERRID=8
		mv "$HOME"/.moneyplex/libmatricagtk.so "$HOME"/.moneyplex/libmatricagtk.so.1 || ERRORS=$(( $ERRORS + $ERRID ))
		sleep 1
	fi
fi

# Wenn VMplayer installiert ist:
# Auf Version 5 aktualisieren
if which vmplayer > /dev/null; then
	if ! vmplayer --version | grep -q "5.0.0"; then
		echo "Vmplayer auf Version 5 aktualisieren..."
		DL_SERVER="http://download.schniewind-it.de/LINUX"
		if [ $(uname -m) = "x86_64" ]; then
			DL_FILE="VMware-Player-5.0.0-812388.x86_64.bundle"
		else
			DL_FILE="VMware-Player-5.0.0-812388.i386.bundle"
		fi
		# Installationsbundle herunterladen
		cd /tmp
		ERRID=16
		wget $DL_SERVER/$DL_FILE || ERRORS=$(( $ERRORS + $ERRID ))
		# Installation ausführen
		echo "Installiere $DL_FILE ..."
		chmod a+x $DL_FILE
		ERRID=32
		./$DL_FILE || ERRORS=$(( $ERRORS + $ERRID ))
		sleep 1
	fi
fi

# Wenn Backintime installiert ist:
# Ordner-Struktur konvertieren und Tray-Icon aktivieren
if which backintime > /dev/null; then
	echo "Backintime: Ordner-Struktur und Konfiguration prüfen..."
	ERRID=64
	# Root-Sicherung, User-Sicherung
	for CONFIG in "/root/.config/backintime/config" "$HOME/.config/backintime/config"; do
		if [ -r $CONFIG ]; then
			if grep -q 'snapshots.continue_on_errors=false' $CONFIG; then
				echo "Passe Backintime-Konfiguration $CONFIG an..."
				sed -i -e 's/\(profile.*\)snapshots\.continue_on_errors=.*/\1snapshots.continue_on_errors=true/' $CONFIG
			fi
			SNAPSHOT_PATH=$(grep "profile1.snapshots.path=" $CONFIG | cut -f2 -d=)
			if mount | grep -q "$SNAPSHOT_PATH" > /dev/null; then
				echo "Passe Datenstruktur auf Medium $SNAPSHOT_PATH an..."
				SNAPSHOT_DIR=$SNAPSHOT_PATH/backintime
				if ls $SNAPSHOT_DIR/2* 2>&1 >/dev/null; then
					USER=root
					HOSTNAME=$(hostname)
					NEW_SNAPSHOT_DIR=$SNAPSHOT_DIR/$HOSTNAME
					mkdir -p $NEW_SNAPSHOT_DIR/$USER/1 && chmod 777 $NEW_SNAPSHOT_DIR && chmod -R 755 $NEW_SNAPSHOT_DIR/$USER && chown -R $USER:$USER $NEW_SNAPSHOT_DIR/$USER && mv $SNAPSHOT_DIR/2* $NEW_SNAPSHOT_DIR/$USER/1/ || ERRORS=$(( $ERRORS + $ERRID ))
				fi
			else
				echo "Backup-Medium $SNAPSHOT_PATH ist nicht eingebunden. Wiederholen Sie dieses Skript, wenn das Backup-Medium angeschlossen ist." >&2
			fi
		fi
		ERRID=$(( $ERRID * 2 ))
	done
	
	# Tray Icon erlauben für User 1000, 1001, 1002, 1003
	ERRID=256
	for uid in 1000 1001 1002 1003; do
		USER=$(grep ":$uid:" /etc/passwd | cut -f1 -d:)
		if [ -n "$USER" ]; then
			echo "Backintime: Tray-Icon erlauben für User $USER..."
			WHITELIST=$(su -c "gsettings get com.canonical.Unity.Panel systray-whitelist" $USER)
			echo "  alte Whitelist: $WHITELIST"
			if ! grep -q "backintime" <<< "$WHITELIST"; then
				# schließende Klammer entfernen und backintime anhängen
				WHITELIST="${WHITELIST%]}, 'backintime', 'backintime-gnome']"
				su -c "gsettings set com.canonical.Unity.Panel systray-whitelist \"$WHITELIST\" 2>/dev/null" $USER || ERRORS=$(( $ERRORS + $ERRID ))
			fi
			echo "  neue Whitelist: $WHITELIST"
		fi
	done
	sleep 1
fi


echo "Fehlersumme: $ERRORS" >&2

#
# Ende Konsolen- und Logfile-Ausgabe
#
} |& tee -a "$LOG"

echo "Fehlersumme: $ERRORS" >&2
[ $ERRORS -eq 0 ] && echo "Fertig. Bitte ab- und neu anmelden. Logfile = $LOG" && sleep 5 && exit 0

# es sind Fehler aufgetreten; Logfile ergänzen und anzeigen
cat > "$LOG.txt" << EOF
=====================================================================
**  Bitte senden Sie diese Informationen an ms@schniewind-it.de
**
** Script-Version: $SV
** HOME:           $HOME
** ERRORS:         $ERRORS
** DIST:           $DIST
** DATUM:          $(date)
=====================================================================


EOF

cat "$LOG" >> "$LOG.txt"

gedit "$LOG.txt" &
exit 0
